@@ -1,10 +1,10 @@
-__version__ = "0.1.1"
+__version__ = "0.1.3"
 
 import asyncio
 from asyncio.subprocess import PIPE
 from os import chdir
 import sys
-from typing import Union
+from typing import List, Union
 
 Command = Union[str, bytes]
 
@@ -21,18 +21,18 @@ async def execute_one(cmd: Command):
     return output
 
 
-async def execute_many(cmds: list[Command]):
+async def execute_many(cmds: List[Command]):
     return await asyncio.gather(*[execute_one(cmd) for cmd in cmds])
 
 
-async def execute(cmd: Union[Command, list[Command]]):
+async def execute(cmd: Union[Command, List[Command]]):
     if type(cmd) == list:
         return await execute_many(cmd)
 
     return await execute_one(cmd)
 
 
-_ = execute
+x = execute
 
 
 def cd(filepath: str):
